clearances

# XMLRésuméLibrary: User Guide

clearance | Element Reference | company

## Name

clearances — One or more security clearances

## Synopsis

### Content Model

    (title?,clearance+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `clearances` element contains one or more security clearances. It is a top-level section of a résumé.

### Parents

`clearances` may be contained in these elements: `resume`

## Examples

    <clearances>
      <clearance>
        <level>Top Secret</level>
        <organization>NSA</organization>
      </clearance>
      <clearance>
        <level>Secret</level>
        <organization>US Navy</organization>
      </clearance>
    </clearances>

clearance | Element Reference | company